@@ -1,86 +1,83 @@
-package Data::GUID;
-
-use warnings;
 use strict;
-
+use warnings;
+package Data::GUID;
+# ABSTRACT: globally unique identifiers
+$Data::GUID::VERSION = '0.050';
 use Carp ();
-use Data::UUID;
-use Sub::Install;
+use Data::UUID 1.148;
+use Sub::Install 0.03;
 
-=head1 NAME
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Data::GUID;
+#pod
+#pod   my $guid = Data::GUID->new;
+#pod
+#pod   my $string = $guid->as_string; # or "$guid"
+#pod
+#pod   my $other_guid = Data::GUID->from_string($string);
+#pod
+#pod   if (($guid <=> $other_guid) == 0) {
+#pod     print "They're the same!\n";
+#pod   }
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Data::GUID provides a simple interface for generating and using globally unique
+#pod identifiers.
+#pod
+#pod =head1 GETTING A NEW GUID
+#pod
+#pod =head2 new
+#pod
+#pod   my $guid = Data::GUID->new;
+#pod
+#pod This method returns a new globally unique identifier.
+#pod
+#pod =cut
 
-Data::GUID - globally unique identifiers
+my $_uuid_gen_obj;
+my $_uuid_gen_pid;
+my $_uuid_gen = sub {
+  return $_uuid_gen_obj if $_uuid_gen_obj
+                        && $_uuid_gen_pid == $$;
 
-=head1 VERSION
+  $_uuid_gen_pid = $$;
+  $_uuid_gen_obj = Data::UUID->new;
+};
 
-version 0.046
-
-=cut
-
-our $VERSION = '0.046';
-
-=head1 SYNOPSIS
-
-  use Data::GUID;
-
-  my $guid = Data::GUID->new;
-
-  my $string = $guid->as_string; # or "$guid"
-
-  my $other_guid = Data::GUID->from_string($string);
-
-  if (($guid <=> $other_guid) == 0) {
-    print "They're the same!\n";
-  }
-
-=head1 DESCRIPTION
-
-Data::GUID provides a simple interface for generating and using globally unique
-identifiers.
-
-=head1 GETTING A NEW GUID
-
-=head2 new
-
-  my $guid = Data::GUID->new;
-
-This method returns a new globally unique identifier.
-
-=cut
-
-my $_uuid_gen = Data::UUID->new;
 sub new {
   my ($class) = @_;
 
-  return $class->from_data_uuid($_uuid_gen->create);
+  return $class->from_data_uuid($_uuid_gen->()->create);
 }
 
-=head1 GUIDS FROM EXISTING VALUES
-
-These method returns a new Data::GUID object for the given GUID value.  In all
-cases, these methods throw an exception if given invalid input.
-
-=head2 from_string
-
-  my $guid = Data::GUID->from_string("B0470602-A64B-11DA-8632-93EBF1C0E05A");
-
-=head2 from_hex
-
-  # note that a hex guid is a guid string without hyphens and with a leading 0x
-  my $guid = Data::GUID->from_hex("0xB0470602A64B11DA863293EBF1C0E05A");
-
-=head2 from_base64
-
-  my $guid = Data::GUID->from_base64("sEcGAqZLEdqGMpPr8cDgWg==");
-
-=head2 from_data_uuid
-
-This method returns a new Data::GUID object if given a Data::UUID value.
-Because Data::UUID values are not blessed and because Data::UUID provides no
-validation method, this method will only throw an exception if the given data
-is of the wrong size.
-
-=cut
+#pod =head1 GUIDS FROM EXISTING VALUES
+#pod
+#pod These method returns a new Data::GUID object for the given GUID value.  In all
+#pod cases, these methods throw an exception if given invalid input.
+#pod
+#pod =head2 from_string
+#pod
+#pod   my $guid = Data::GUID->from_string("B0470602-A64B-11DA-8632-93EBF1C0E05A");
+#pod
+#pod =head2 from_hex
+#pod
+#pod   # note that a hex guid is a guid string without hyphens and with a leading 0x
+#pod   my $guid = Data::GUID->from_hex("0xB0470602A64B11DA863293EBF1C0E05A");
+#pod
+#pod =head2 from_base64
+#pod
+#pod   my $guid = Data::GUID->from_base64("sEcGAqZLEdqGMpPr8cDgWg==");
+#pod
+#pod =head2 from_data_uuid
+#pod
+#pod This method returns a new Data::GUID object if given a Data::UUID value.
+#pod Because Data::UUID values are not blessed and because Data::UUID provides no
+#pod validation method, this method will only throw an exception if the given data
+#pod is of the wrong size.
+#pod
+#pod =cut
 
 sub from_data_uuid {
   my ($class, $value) = @_;
@@ -90,18 +87,18 @@ sub from_data_uuid {
   bless \$value => $class;
 }
 
-=head1 IDENTIFYING GUIDS
-
-=head2 string_guid_regex
-
-=head2 hex_guid_regex
-
-=head2 base64_guid_regex
-
-These methods return regex objects that match regex strings of the appropriate
-type.
-
-=cut
+#pod =head1 IDENTIFYING GUIDS
+#pod
+#pod =head2 string_guid_regex
+#pod
+#pod =head2 hex_guid_regex
+#pod
+#pod =head2 base64_guid_regex
+#pod
+#pod These methods return regex objects that match regex strings of the appropriate
+#pod type.
+#pod
+#pod =cut
 
 my ($hex, $base64, %type);
 
@@ -133,7 +130,7 @@ sub _install_from_method {
     my ($class, $string) = @_;
     $string ||= q{}; # to avoid (undef =~) warning
     Carp::croak qq{"$string" is not a valid $type GUID} if $string !~ $regex;
-    $class->from_data_uuid( $_uuid_gen->$alien_from_method($string) );
+    $class->from_data_uuid( $_uuid_gen->()->$alien_from_method($string) );
   };
 
   Sub::Install::install_sub({ code => $our_from_code, as => "from_$type" });
@@ -146,7 +143,7 @@ sub _install_as_method {
 
   my $our_to_method = sub {
     my ($self) = @_;
-    $_uuid_gen->$alien_to_method( $self->as_binary );
+    $_uuid_gen->()->$alien_to_method( $self->as_binary );
   };
 
   Sub::Install::install_sub({ code => $our_to_method, as => "as_$type" });
@@ -184,17 +181,17 @@ sub _from_multitype {
   }
 }
 
-=head2 from_any_string
-
-  my $string = get_string_from_ether;
-
-  my $guid = Data::GUID->from_any_string($string);
-
-This method returns a Data::GUID object for the given string, trying all known
-string interpretations.  An exception is thrown if the value is not a valid
-GUID string.
-
-=cut
+#pod =head2 from_any_string
+#pod
+#pod   my $string = get_string_from_ether;
+#pod
+#pod   my $guid = Data::GUID->from_any_string($string);
+#pod
+#pod This method returns a Data::GUID object for the given string, trying all known
+#pod string interpretations.  An exception is thrown if the value is not a valid
+#pod GUID string.
+#pod
+#pod =cut
 
 BEGIN { # possibly unnecessary -- rjbs, 2006-03-11
   Sub::Install::install_sub({
@@ -203,17 +200,17 @@ BEGIN { # possibly unnecessary -- rjbs, 2006-03-11
   });
 }
 
-=head2 best_guess
-
-  my $value = get_value_from_ether;
-
-  my $guid = Data::GUID->best_guess($value);
-
-This method returns a Data::GUID object for the given value, trying everything
-it can.  It works like C<L</from_any_string>>, but will also accept Data::UUID
-values.  (In effect, this means that any sixteen byte value is acceptable.)
-
-=cut
+#pod =head2 best_guess
+#pod
+#pod   my $value = get_value_from_ether;
+#pod
+#pod   my $guid = Data::GUID->best_guess($value);
+#pod
+#pod This method returns a Data::GUID object for the given value, trying everything
+#pod it can.  It works like C<L</from_any_string>>, but will also accept Data::UUID
+#pod values.  (In effect, this means that any sixteen byte value is acceptable.)
+#pod
+#pod =cut
 
 BEGIN { # possibly unnecessary -- rjbs, 2006-03-11
   Sub::Install::install_sub({
@@ -222,42 +219,42 @@ BEGIN { # possibly unnecessary -- rjbs, 2006-03-11
   });
 }
 
-=head1 GUIDS INTO STRINGS
+#pod =head1 GUIDS INTO STRINGS
+#pod
+#pod These methods return various string representations of a GUID.
+#pod
+#pod =head2 as_string
+#pod
+#pod This method returns a "traditional" GUID/UUID string representation.  This is
+#pod five hexadecimal strings, delimited by hyphens.  For example:
+#pod
+#pod   B0470602-A64B-11DA-8632-93EBF1C0E05A
+#pod
+#pod This method is also used to stringify Data::GUID objects.
+#pod
+#pod =head2 as_hex
+#pod
+#pod This method returns a plain hexadecimal representation of the GUID, with a
+#pod leading C<0x>.  For example:
+#pod
+#pod   0xB0470602A64B11DA863293EBF1C0E05A
+#pod
+#pod =head2 as_base64
+#pod
+#pod This method returns a base-64 string representation of the GUID.  For example:
+#pod
+#pod   sEcGAqZLEdqGMpPr8cDgWg==
+#pod
+#pod =cut
 
-These methods return various string representations of a GUID.
-
-=head2 as_string
-
-This method returns a "traditional" GUID/UUID string representation.  This is
-five hexadecimal strings, delimited by hyphens.  For example:
-
-  B0470602-A64B-11DA-8632-93EBF1C0E05A
-
-This method is also used to stringify Data::GUID objects.
-
-=head2 as_hex
-
-This method returns a plain hexadecimal representation of the GUID, with a
-leading C<0x>.  For example:
-
-  0xB0470602A64B11DA863293EBF1C0E05A
-
-=head2 as_base64
-
-This method returns a base-64 string representation of the GUID.  For example:
-
-  sEcGAqZLEdqGMpPr8cDgWg==
-
-=cut
-
-=head1 OTHER METHODS
-
-=head2 compare_to_guid
-
-This method compares a GUID to another GUID and returns -1, 0, or 1, as do
-other comparison routines.
-
-=cut
+#pod =head1 OTHER METHODS
+#pod
+#pod =head2 compare_to_guid
+#pod
+#pod This method compares a GUID to another GUID and returns -1, 0, or 1, as do
+#pod other comparison routines.
+#pod
+#pod =cut
 
 sub compare_to_guid {
   my ($self, $other) = @_;
@@ -265,16 +262,16 @@ sub compare_to_guid {
   my $other_binary
     = eval { $other->isa('Data::GUID') } ? $other->as_binary : $other;
 
-  $_uuid_gen->compare($self->as_binary, $other_binary);
+  $_uuid_gen->()->compare($self->as_binary, $other_binary);
 }
 
-=head2 as_binary
-
-This method returns the packed binary representation of the GUID.  At present
-this method relies on Data::GUID's underlying use of Data::UUID.  It is not
-guaranteed to continue to work the same way, or at all.  I<Caveat invocator>.
-
-=cut
+#pod =head2 as_binary
+#pod
+#pod This method returns the packed binary representation of the GUID.  At present
+#pod this method relies on Data::GUID's underlying use of Data::UUID.  It is not
+#pod guaranteed to continue to work the same way, or at all.  I<Caveat invocator>.
+#pod
+#pod =cut
 
 sub as_binary {
   my ($self) = @_;
@@ -286,42 +283,42 @@ use overload
   '<=>' => sub { ($_[2] ? -1 : 1) * $_[0]->compare_to_guid($_[1]) },
   fallback => 1;
 
-=head1 IMPORTING
+#pod =head1 IMPORTING
+#pod
+#pod Data::GUID does not export any subroutines by default, but it provides a few
+#pod routines which will be imported on request.  These routines may be called as
+#pod class methods, or may be imported to be called as subroutines.  Calling them by
+#pod fully qualified name is incorrect.
+#pod
+#pod   use Data::GUID qw(guid);
+#pod
+#pod   my $guid = guid;             # OK
+#pod   my $guid = Data::GUID->guid; # OK
+#pod   my $guid = Data::GUID::guid; # NOT OK
+#pod
+#pod =cut
 
-Data::GUID does not export any subroutines by default, but it provides a few
-routines which will be imported on request.  These routines may be called as
-class methods, or may be imported to be called as subroutines.  Calling them by
-fully qualified name is incorrect.
-
-  use Data::GUID qw(guid);
-
-  my $guid = guid;             # OK
-  my $guid = Data::GUID->guid; # OK
-  my $guid = Data::GUID::guid; # NOT OK
-
-=cut
-
-=head2 guid
-
-This routine returns a new Data::GUID object.
-
-=head2 guid_string
-
-This returns the string representation of a new GUID.
-
-=head2 guid_hex
-
-This returns the hex representation of a new GUID.
-
-=head2 guid_base64
-
-This returns the base64 representation of a new GUID.
-
-=head2 guid_from_anything
-
-This returns the result of calling the C<L</from_any_string>> method.
-
-=cut
+#pod =head2 guid
+#pod
+#pod This routine returns a new Data::GUID object.
+#pod
+#pod =head2 guid_string
+#pod
+#pod This returns the string representation of a new GUID.
+#pod
+#pod =head2 guid_hex
+#pod
+#pod This returns the hex representation of a new GUID.
+#pod
+#pod =head2 guid_base64
+#pod
+#pod This returns the base64 representation of a new GUID.
+#pod
+#pod =head2 guid_from_anything
+#pod
+#pod This returns the result of calling the C<L</from_any_string>> method.
+#pod
+#pod =cut
 
 BEGIN {
   Sub::Install::install_sub({ code => 'new', as => 'guid' });
@@ -353,43 +350,230 @@ BEGIN {
     ((map { "guid_$_" } keys %type), 'guid');
 }
 
-use Sub::Exporter -setup => {
+use Sub::Exporter 0.90 -setup => {
   exports => {
     %exports, # defined just above
     guid_from_anything => sub { _curry_class($_[0], 'from_any_string', 1) },
   }
 };
 
+#pod =head1 TODO
+#pod
+#pod =for :list
+#pod * add namespace support
+#pod * remove dependency on wretched Data::UUID
+#pod * make it work on 5.005
+#pod
+#pod =cut
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Data::GUID - globally unique identifiers
+
+=head1 VERSION
+
+version 0.050
+
+=head1 SYNOPSIS
+
+  use Data::GUID;
+
+  my $guid = Data::GUID->new;
+
+  my $string = $guid->as_string; # or "$guid"
+
+  my $other_guid = Data::GUID->from_string($string);
+
+  if (($guid <=> $other_guid) == 0) {
+    print "They're the same!\n";
+  }
+
+=head1 DESCRIPTION
+
+Data::GUID provides a simple interface for generating and using globally unique
+identifiers.
+
+=head1 PERL VERSION SUPPORT
+
+This module has an extremely long-term perl support period.  That means it will
+not require a version of perl released fewer than ten years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
+=head1 GETTING A NEW GUID
+
+=head2 new
+
+  my $guid = Data::GUID->new;
+
+This method returns a new globally unique identifier.
+
+=head1 GUIDS FROM EXISTING VALUES
+
+These method returns a new Data::GUID object for the given GUID value.  In all
+cases, these methods throw an exception if given invalid input.
+
+=head2 from_string
+
+  my $guid = Data::GUID->from_string("B0470602-A64B-11DA-8632-93EBF1C0E05A");
+
+=head2 from_hex
+
+  # note that a hex guid is a guid string without hyphens and with a leading 0x
+  my $guid = Data::GUID->from_hex("0xB0470602A64B11DA863293EBF1C0E05A");
+
+=head2 from_base64
+
+  my $guid = Data::GUID->from_base64("sEcGAqZLEdqGMpPr8cDgWg==");
+
+=head2 from_data_uuid
+
+This method returns a new Data::GUID object if given a Data::UUID value.
+Because Data::UUID values are not blessed and because Data::UUID provides no
+validation method, this method will only throw an exception if the given data
+is of the wrong size.
+
+=head1 IDENTIFYING GUIDS
+
+=head2 string_guid_regex
+
+=head2 hex_guid_regex
+
+=head2 base64_guid_regex
+
+These methods return regex objects that match regex strings of the appropriate
+type.
+
+=head2 from_any_string
+
+  my $string = get_string_from_ether;
+
+  my $guid = Data::GUID->from_any_string($string);
+
+This method returns a Data::GUID object for the given string, trying all known
+string interpretations.  An exception is thrown if the value is not a valid
+GUID string.
+
+=head2 best_guess
+
+  my $value = get_value_from_ether;
+
+  my $guid = Data::GUID->best_guess($value);
+
+This method returns a Data::GUID object for the given value, trying everything
+it can.  It works like C<L</from_any_string>>, but will also accept Data::UUID
+values.  (In effect, this means that any sixteen byte value is acceptable.)
+
+=head1 GUIDS INTO STRINGS
+
+These methods return various string representations of a GUID.
+
+=head2 as_string
+
+This method returns a "traditional" GUID/UUID string representation.  This is
+five hexadecimal strings, delimited by hyphens.  For example:
+
+  B0470602-A64B-11DA-8632-93EBF1C0E05A
+
+This method is also used to stringify Data::GUID objects.
+
+=head2 as_hex
+
+This method returns a plain hexadecimal representation of the GUID, with a
+leading C<0x>.  For example:
+
+  0xB0470602A64B11DA863293EBF1C0E05A
+
+=head2 as_base64
+
+This method returns a base-64 string representation of the GUID.  For example:
+
+  sEcGAqZLEdqGMpPr8cDgWg==
+
+=head1 OTHER METHODS
+
+=head2 compare_to_guid
+
+This method compares a GUID to another GUID and returns -1, 0, or 1, as do
+other comparison routines.
+
+=head2 as_binary
+
+This method returns the packed binary representation of the GUID.  At present
+this method relies on Data::GUID's underlying use of Data::UUID.  It is not
+guaranteed to continue to work the same way, or at all.  I<Caveat invocator>.
+
+=head1 IMPORTING
+
+Data::GUID does not export any subroutines by default, but it provides a few
+routines which will be imported on request.  These routines may be called as
+class methods, or may be imported to be called as subroutines.  Calling them by
+fully qualified name is incorrect.
+
+  use Data::GUID qw(guid);
+
+  my $guid = guid;             # OK
+  my $guid = Data::GUID->guid; # OK
+  my $guid = Data::GUID::guid; # NOT OK
+
+=head2 guid
+
+This routine returns a new Data::GUID object.
+
+=head2 guid_string
+
+This returns the string representation of a new GUID.
+
+=head2 guid_hex
+
+This returns the hex representation of a new GUID.
+
+=head2 guid_base64
+
+This returns the base64 representation of a new GUID.
+
+=head2 guid_from_anything
+
+This returns the result of calling the C<L</from_any_string>> method.
+
 =head1 TODO
 
-=over
+=over 4
 
-=item * add namespace support
+=item *
 
-=item * remove dependency on wretched Data::UUID
+add namespace support
 
-=item * make it work on 5.005
+=item *
+
+remove dependency on wretched Data::UUID
+
+=item *
+
+make it work on 5.005
 
 =back
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-data-guid@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2006 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2006 Ricardo Signes, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
